/**
 * @internal
 */
export declare function shortenString(str: string, extraShort?: boolean): string;
/**
 * This function shortens an address if it is a valid EVM address.
 *
 * @param address - The address to shorten
 * @param extraShort - If true, show the first 4 and last 3 characters
 * @returns The shortened address
 *
 * @remarks
 * Note that this function will not check if the address is an ENS.
 *
 * @example Calling shortenAddress with extraShort set to true
 * ```ts
 * const address = shortenIfAddress("0x1234567890123456789012345678901234567890", true); // result will be "0x1234...890"
 * ```
 *
 */
export declare function shortenAddress(address?: string, extraShort?: boolean): string;
/**
 * @internal
 */
export declare function shortenIfAddress(address?: string | null | false, extraShort?: boolean): string;
/**
 * @internal
 */
export declare function isEnsName(name: string): boolean;
/**
 * @internal
 */
export declare function isPossibleEVMAddress(address?: string, ignoreEns?: boolean): boolean;
//# sourceMappingURL=addresses.d.ts.map